TTF_CreateGPUTextEngine

Function TTF_CreateGPUTextEngine 

pub unsafe extern "C" fn TTF_CreateGPUTextEngine(
    device: *mut SDL_GPUDevice,
) -> *mut TTF_TextEngine
Create a text engine for drawing text with the SDL GPU API.

Parameter: device the SDL_GPUDevice to use for creating textures and drawing text.

Returns: a TTF_TextEngine object or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the device.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_CreateGPUTextEngineWithProperties

See Also: TTF_DestroyGPUTextEngine

See Also: TTF_GetGPUTextDrawData