TTF_CreateRendererTextEngineWithProperties

Function TTF_CreateRendererTextEngineWithProperties 

pub unsafe extern "C" fn TTF_CreateRendererTextEngineWithProperties(
    props: SDL_PropertiesID,
) -> *mut TTF_TextEngine
Create a text engine for drawing text on an SDL renderer, with the specified properties.

These are the supported properties:

  • TTF_PROP_RENDERER_TEXT_ENGINE_RENDERER_POINTER: the renderer to use for creating textures and drawing text
  • TTF_PROP_RENDERER_TEXT_ENGINE_ATLAS_TEXTURE_SIZE_NUMBER: the size of the texture atlas

Parameter: props the properties to use.

Returns: a TTF_TextEngine object or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the renderer.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_CreateRendererTextEngine

See Also: TTF_DestroyRendererTextEngine

See Also: TTF_DrawRendererText