TTF_CreateText

Function TTF_CreateText 

pub unsafe extern "C" fn TTF_CreateText(
    engine: *mut TTF_TextEngine,
    font: *mut TTF_Font,
    text: *const c_char,
    length: usize,
) -> *mut TTF_Text
Create a text object from UTF-8 text and a text engine.

Parameter: engine the text engine to use when creating the text object, may be NULL.

Parameter: font the font to render with.

Parameter: text the text to use, in UTF-8 encoding.

Parameter: length the length of the text, in bytes, or 0 for null terminated text.

Returns: a TTF_Text object or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the font and text engine.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_DestroyText