TTF_DeleteTextString

Function TTF_DeleteTextString 

pub unsafe extern "C" fn TTF_DeleteTextString(
    text: *mut TTF_Text,
    offset: c_int,
    length: c_int,
) -> bool
Delete UTF-8 text from a text object.

This function may cause the internal text representation to be rebuilt.

Parameter: text the TTF_Text to modify.

Parameter: offset the offset, in bytes, from the beginning of the string if >= 0, the offset from the end of the string if < 0. Note that this does not do UTF-8 validation, so you should only delete at UTF-8 sequence boundaries.

Parameter: length the length of text to delete, in bytes, or -1 for the remainder of the string.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_AppendTextString

See Also: TTF_InsertTextString

See Also: TTF_SetTextString