TTF_GetFontScript

Function TTF_GetFontScript 

pub unsafe extern "C" fn TTF_GetFontScript(
    font: *mut TTF_Font,
) -> Uint32
Get the script used for text shaping a font.

Parameter: font the font to query.

Returns: an ISO 15924 code or 0 if a script hasn’t been set.

Thread Safety: This function should be called on the thread that created the font.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_TagToString