TTF_GetPreviousTextSubString

Function TTF_GetPreviousTextSubString 

pub unsafe extern "C" fn TTF_GetPreviousTextSubString(
    text: *mut TTF_Text,
    substring: *const TTF_SubString,
    previous: *mut TTF_SubString,
) -> bool
Get the previous substring in a text object

If called at the start of the text, this will return a zero length substring with the TTF_SUBSTRING_TEXT_START flag set.

Parameter: text the TTF_Text to query.

Parameter: substring the TTF_SubString to query.

Parameter: previous a pointer filled in with the previous substring in the text object.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.