TTF_GetStringSizeWrapped

Function TTF_GetStringSizeWrapped 

pub unsafe extern "C" fn TTF_GetStringSizeWrapped(
    font: *mut TTF_Font,
    text: *const c_char,
    length: usize,
    wrap_width: c_int,
    w: *mut c_int,
    h: *mut c_int,
) -> bool
Calculate the dimensions of a rendered string of UTF-8 text.

This will report the width and height, in pixels, of the space that the specified string will take to fully render.

Text is wrapped to multiple lines on line endings and on word boundaries if it extends beyond wrap_width in pixels.

If wrap_width is 0, this function will only wrap on newline characters.

Parameter: font the font to query.

Parameter: text text to calculate, in UTF-8 encoding.

Parameter: length the length of the text, in bytes, or 0 for null terminated text.

Parameter: wrap_width the maximum width or 0 to wrap on newline characters.

Parameter: w will be filled with width, in pixels, on return.

Parameter: h will be filled with height, in pixels, on return.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the font.

Available Since: This function is available since SDL_ttf 3.0.0.