TTF_GetTextDirection

Function TTF_GetTextDirection 

pub unsafe extern "C" fn TTF_GetTextDirection(
    text: *mut TTF_Text,
) -> TTF_Direction
Get the direction to be used for text shaping a text object.

This defaults to the direction of the font used by the text object.

Parameter: text the text to query.

Returns: the direction to be used for text shaping.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.