TTF_GetTextEngine

Function TTF_GetTextEngine 

pub unsafe extern "C" fn TTF_GetTextEngine(
    text: *mut TTF_Text,
) -> *mut TTF_TextEngine
Get the text engine used by a text object.

Parameter: text the TTF_Text to query.

Returns: the TTF_TextEngine used by the text on success or NULL on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_SetTextEngine