TTF_GetTextPosition

Function TTF_GetTextPosition 

pub unsafe extern "C" fn TTF_GetTextPosition(
    text: *mut TTF_Text,
    x: *mut c_int,
    y: *mut c_int,
) -> bool
Get the position of a text object.

Parameter: text the TTF_Text to query.

Parameter: x a pointer filled in with the x offset of the upper left corner of this text in pixels, may be NULL.

Parameter: y a pointer filled in with the y offset of the upper left corner of this text in pixels, may be NULL.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_SetTextPosition