TTF_GetTextSubStringForPoint

Function TTF_GetTextSubStringForPoint 

pub unsafe extern "C" fn TTF_GetTextSubStringForPoint(
    text: *mut TTF_Text,
    x: c_int,
    y: c_int,
    substring: *mut TTF_SubString,
) -> bool
Get the portion of a text string that is closest to a point.

This will return the closest substring of text to the given point.

Parameter: text the TTF_Text to query.

Parameter: x the x coordinate relative to the left side of the text, may be outside the bounds of the text area.

Parameter: y the y coordinate relative to the top side of the text, may be outside the bounds of the text area.

Parameter: substring a pointer filled in with the closest substring of text to the given point.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.