TTF_GetTextSubStringsForRange

Function TTF_GetTextSubStringsForRange 

pub unsafe extern "C" fn TTF_GetTextSubStringsForRange(
    text: *mut TTF_Text,
    offset: c_int,
    length: c_int,
    count: *mut c_int,
) -> *mut *mut TTF_SubString
Get the substrings of a text object that contain a range of text.

Parameter: text the TTF_Text to query.

Parameter: offset a byte offset into the text string.

Parameter: length the length of the range being queried, in bytes, or -1 for the remainder of the string.

Parameter: count a pointer filled in with the number of substrings returned, may be NULL.

Returns: a NULL terminated array of substring pointers or NULL on failure; call SDL_GetError() for more information. This is a single allocation that should be freed with SDL_free() when it is no longer needed.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.