TTF_Init

Function TTF_Init 

pub unsafe extern "C" fn TTF_Init() -> bool
Initialize SDL_ttf.

You must successfully call this function before it is safe to call any other function in this library.

It is safe to call this more than once, and each successful TTF_Init() call should be paired with a matching TTF_Quit() call.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_Quit