TTF_InsertTextString

Function TTF_InsertTextString 

pub unsafe extern "C" fn TTF_InsertTextString(
    text: *mut TTF_Text,
    offset: c_int,
    string: *const c_char,
    length: usize,
) -> bool
Insert UTF-8 text into a text object.

This function may cause the internal text representation to be rebuilt.

Parameter: text the TTF_Text to modify.

Parameter: offset the offset, in bytes, from the beginning of the string if >= 0, the offset from the end of the string if < 0. Note that this does not do UTF-8 validation, so you should only insert at UTF-8 sequence boundaries.

Parameter: string the UTF-8 text to insert.

Parameter: length the length of the text, in bytes, or 0 for null terminated text.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Thread Safety: This function should be called on the thread that created the text.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_AppendTextString

See Also: TTF_DeleteTextString

See Also: TTF_SetTextString