pub unsafe extern "C" fn TTF_SetTextFont(
text: *mut TTF_Text,
font: *mut TTF_Font,
) -> boolExpand description
Set the font used by a text object.
When a text object has a font, any changes to the font will automatically regenerate the text. If you set the font to NULL, the text will continue to render but changes to the font will no longer affect the text.
This function may cause the internal text representation to be rebuilt.
Parameter: text the TTF_Text to modify.
Parameter: font the font to use, may be NULL.
Returns: false if the text pointer is null; otherwise, true. call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_GetTextFont