TTF_TagToString

Function TTF_TagToString 

pub unsafe extern "C" fn TTF_TagToString(
    tag: Uint32,
    string: *mut c_char,
    size: usize,
)
Convert from a 32-bit tag to a 4 character string.

Parameter: tag the 32-bit tag to convert.

Parameter: string a pointer filled in with the 4 character representation of the tag.

Parameter: size the size of the buffer pointed at by string, should be at least 4.

Thread Safety: It is safe to call this function from any thread.

Available Since: This function is available since SDL_ttf 3.0.0.

See Also: TTF_TagToString