TTF_Text

Struct TTF_Text 

#[repr(C)]
pub struct TTF_Text { pub text: *mut c_char, pub num_lines: c_int, pub refcount: c_int, pub internal: *mut TTF_TextData, }
Text created with TTF_CreateText()

Available Since: This struct is available since SDL_ttf 3.0.0.

See Also: TTF_CreateText

See Also: TTF_GetTextProperties

See Also: TTF_DestroyText

Fields

text: *mut c_char

< A copy of the UTF-8 string that this text object represents, useful for layout, debugging and retrieving substring text. This is updated when the text object is modified and will be freed automatically when the object is destroyed.

num_lines: c_int

< The number of lines in the text, 0 if it’s empty

refcount: c_int

< Application reference count, used when freeing surface

internal: *mut TTF_TextData

< Private