TTF_FontStyleFlags

Type Alias TTF_FontStyleFlags 

pub type TTF_FontStyleFlags = Uint32;
Font style flags for TTF_Font

These are the flags which can be used to set the style of a font in SDL_ttf. A combination of these flags can be used with functions that set or query font style, such as TTF_SetFontStyle or TTF_GetFontStyle.

Available Since: This datatype is available since SDL_ttf 3.0.0.

See Also: TTF_SetFontStyle

See Also: TTF_GetFontStyle