pub unsafe extern "C" fn TTF_AddFallbackFont(
font: *mut TTF_Font,
fallback: *mut TTF_Font,
) -> boolExpand description
Add a fallback font.
Add a font that will be used for glyphs that are not in the current font. The fallback font should have the same size and style as the current font.
If there are multiple fallback fonts, they are used in the order added.
This updates any TTF_Text objects using this font.
Parameter: font the font to modify.
Parameter: fallback the font to add as a fallback.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created both fonts.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_ClearFallbackFonts
See Also: TTF_RemoveFallbackFont