pub unsafe extern "C" fn TTF_AppendTextString(
text: *mut TTF_Text,
string: *const c_char,
length: usize,
) -> boolExpand description
Append UTF-8 text to a text object.
This function may cause the internal text representation to be rebuilt.
Parameter: text the TTF_Text to modify.
Parameter: string the UTF-8 text to insert.
Parameter: length the length of the text, in bytes, or 0 for null terminated text.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_DeleteTextString
See Also: TTF_InsertTextString
See Also: TTF_SetTextString