pub unsafe extern "C" fn TTF_CreateGPUTextEngineWithProperties(
props: SDL_PropertiesID,
) -> *mut TTF_TextEngineExpand description
Create a text engine for drawing text with the SDL GPU API, with the specified properties.
These are the supported properties:
TTF_PROP_GPU_TEXT_ENGINE_DEVICE_POINTER: the SDL_GPUDevice to use for creating textures and drawing text.TTF_PROP_GPU_TEXT_ENGINE_ATLAS_TEXTURE_SIZE_NUMBER: the size of the texture atlas
Parameter: props the properties to use.
Returns: a TTF_TextEngine object or NULL on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the device.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_CreateGPUTextEngine
See Also: TTF_DestroyGPUTextEngine
See Also: TTF_GetGPUTextDrawData