pub unsafe extern "C" fn TTF_CreateSurfaceTextEngine() -> *mut TTF_TextEngineExpand description
Create a text engine for drawing text on SDL surfaces.
Returns: a TTF_TextEngine object or NULL on failure; call SDL_GetError() for more information.
Thread Safety: It is safe to call this function from any thread.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_DestroySurfaceTextEngine
See Also: TTF_DrawSurfaceText