pub unsafe extern "C" fn TTF_GetNextTextSubString(
text: *mut TTF_Text,
substring: *const TTF_SubString,
next: *mut TTF_SubString,
) -> boolExpand description
Get the next substring in a text object
If called at the end of the text, this will return a zero length substring with the TTF_SUBSTRING_TEXT_END flag set.
Parameter: text the TTF_Text to query.
Parameter: substring the TTF_SubString to query.
Parameter: next a pointer filled in with the next substring.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.