pub unsafe extern "C" fn TTF_GetStringSize(
font: *mut TTF_Font,
text: *const c_char,
length: usize,
w: *mut c_int,
h: *mut c_int,
) -> boolExpand description
Calculate the dimensions of a rendered string of UTF-8 text.
This will report the width and height, in pixels, of the space that the specified string will take to fully render.
Parameter: font the font to query.
Parameter: text text to calculate, in UTF-8 encoding.
Parameter: length the length of the text, in bytes, or 0 for null terminated text.
Parameter: w will be filled with width, in pixels, on return.
Parameter: h will be filled with height, in pixels, on return.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the font.
Available Since: This function is available since SDL_ttf 3.0.0.