pub unsafe extern "C" fn TTF_GetTextScript(
text: *mut TTF_Text,
) -> Uint32Expand description
Get the script used for text shaping a text object.
This defaults to the script of the font used by the text object.
Parameter: text the text to query.
Returns: an ISO 15924 code or 0 if a script hasn’t been set on either the text object or the font.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_TagToString