pub unsafe extern "C" fn TTF_GetTextSubString(
text: *mut TTF_Text,
offset: c_int,
substring: *mut TTF_SubString,
) -> boolExpand description
Get the substring of a text object that surrounds a text offset.
If offset is less than 0, this will return a zero length substring at the
beginning of the text with the TTF_SUBSTRING_TEXT_START flag set. If
offset is greater than or equal to the length of the text string, this
will return a zero length substring at the end of the text with the
TTF_SUBSTRING_TEXT_END flag set.
Parameter: text the TTF_Text to query.
Parameter: offset a byte offset into the text string.
Parameter: substring a pointer filled in with the substring containing the offset.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.