pub unsafe extern "C" fn TTF_SetFontDirection(
font: *mut TTF_Font,
direction: TTF_Direction,
) -> boolExpand description
Set the direction to be used for text shaping by a font.
This function only supports left-to-right text shaping if SDL_ttf was not built with HarfBuzz support.
This updates any TTF_Text objects using this font.
Parameter: font the font to modify.
Parameter: direction the new direction for text to flow.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the font.
Available Since: This function is available since SDL_ttf 3.0.0.