pub unsafe extern "C" fn TTF_SetFontScript(
font: *mut TTF_Font,
script: Uint32,
) -> boolExpand description
Set the script to be used for text shaping by a font.
This returns false if SDL_ttf isn’t built with HarfBuzz support.
This updates any TTF_Text objects using this font.
Parameter: font the font to modify.
Parameter: script an ISO 15924 code .
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the font.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_StringToTag