pub unsafe extern "C" fn TTF_SetTextDirection(
text: *mut TTF_Text,
direction: TTF_Direction,
) -> boolExpand description
Set the direction to be used for text shaping a text object.
This function only supports left-to-right text shaping if SDL_ttf was not built with HarfBuzz support.
Parameter: text the text to modify.
Parameter: direction the new direction for text to flow.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.