pub unsafe extern "C" fn TTF_SetTextEngine(
text: *mut TTF_Text,
engine: *mut TTF_TextEngine,
) -> boolExpand description
Set the text engine used by a text object.
This function may cause the internal text representation to be rebuilt.
Parameter: text the TTF_Text to modify.
Parameter: engine the text engine to use for drawing.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_GetTextEngine