pub unsafe extern "C" fn TTF_SetTextPosition(
text: *mut TTF_Text,
x: c_int,
y: c_int,
) -> boolExpand description
Set the position of a text object.
This can be used to position multiple text objects within a single wrapping text area.
This function may cause the internal text representation to be rebuilt.
Parameter: text the TTF_Text to modify.
Parameter: x the x offset of the upper left corner of this text in pixels.
Parameter: y the y offset of the upper left corner of this text in pixels.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Thread Safety: This function should be called on the thread that created the text.
Available Since: This function is available since SDL_ttf 3.0.0.
See Also: TTF_GetTextPosition