#[repr(C)]pub struct TTF_SubString {
pub flags: TTF_SubStringFlags,
pub offset: c_int,
pub length: c_int,
pub line_index: c_int,
pub cluster_index: c_int,
pub rect: SDL_Rect,
}Expand description
The representation of a substring within text.
Available Since: This struct is available since SDL_ttf 3.0.0.
See Also: TTF_GetNextTextSubString
See Also: TTF_GetPreviousTextSubString
See Also: TTF_GetTextSubString
See Also: TTF_GetTextSubStringForLine
See Also: TTF_GetTextSubStringForPoint
See Also: TTF_GetTextSubStringsForRange
Fields
flags: TTF_SubStringFlags< The flags for this substring
offset: c_int< The byte offset from the beginning of the text
length: c_int< The byte length starting at the offset
line_index: c_int< The index of the line that contains this substring
cluster_index: c_int< The internal cluster index, used for quickly iterating
rect: SDL_Rect< The rectangle, relative to the top left of the text, containing the substring